URI.js - Custom Build
Description: URI.js is a Javascript library for working with URLs.

# URI.js

## Building URI.js

Warning: The output of this "build tool" is not compatible with module loaders (like RequireJS), because it only concatenates and minifies files. Only use this if you plan on loading the file by way of `<script>` element.

Choose the Modules you want to include in your custom build of URI.js:

- IPv6.js - Support for IPv6 Addresses
- punycode.js - Support for IDN Addresses
- SecondLevelDomains.js - Support for resolving SLDs
- URI.js - Base URI.js
- URITemplate.js - Support for URI Templates
- jquery.URI.js - jQuery Plugin

Optional "Fragment Abuse" plugins:

- No Fragment abuse
- URI.fragmentQuery.js - support for Query String Fragments
- URI.fragmentURI.js - support for URI Fragments

## Custom Built URI.js

your custom built `URI.js` or copy the following code:

This "build tool" does nothing but downloading the selected files, concatenating them and pushing them through Closure Compiler. Since Closure Compiler is running on a different domain, this trick will only work on modern browsers. I'm sorry for the ~2% of you IE users. You'll have to do this manually.